*****************
:mod:`mopidy.mpd`
*****************

MPD protocol implementation
===========================

.. automodule:: mopidy.mpd.frontend
    :synopsis: Our MPD protocol implementation.
    :members:
    :undoc-members:


MPD server implementation
=========================

.. automodule:: mopidy.mpd.server
    :synopsis: Our MPD server implementation.
    :members:
    :undoc-members:

.. inheritance-diagram:: mopidy.mpd.server
